import architecture from "./architecture.txt?raw";
import provinces from "./provinces.txt?raw";
import {bat2, lore1, stare0} from "../../skills.ts";
import {compileNewMap} from "../../newmap.ts";
import {compile} from "../../vnscene.ts";

const mapZoo = compileNewMap({
  id: "mapZoo",
  data: {
    architecture: architecture,
    provinces: provinces,
  },
  pickups: {
    // "*": itemGecko,
    stat: {primary: "AGI", secondary: "PSI"},
    // "!": {"item": "colonialGoose"},
  },
  provinces: {
    a: "Zoo",
    b: "Gator Pen",
    c: "Food Storage"
  },
  checks: {
    1: {
      label:
        "The gator pen appears to be locked. " +
        "Some bats behind the barred gate are amusing " +
        "themselves by swooping and darting just out of the alligators' reach.",
      options: [
        {
          skills: () => [lore1],
          locked: "That wall sure does look impenetrable.",
          unlockable: "I see a failure in the construction.",
          unlockScene: compile([
            "I dig my clawed fingers into a crack between the bricks and feel the concrete give way.",
            "This structure, built by mortals, is impermanent. Soon none of it will exist.",
            "I rip another clump of brittle earth from the crack, no longer invisible.",
            "And another. When the gap's wide enough to crawl through, I climb in."
          ])
        },
        {
          skills: () => [stare0],
          locked: "The bats are happy by themselves.",
          unlockable: "These bats could be enjoying themselves so much more.",
          unlockScene: compile([
            "I hold my face to the bars. One bat looks at me.",
            "\"Here, little bat\" -- I think before I say it. No, relate to it as an equal.",
            "What does it really want?",
            "What does any mortal want? It wants to feel a whole lot better --",
            "So stare --",
            "...",
            "... Now it breaks. Like any mortal, but with a loud, high-pitched squeal.",
            "Still dripping, it flaps unsurely to the door and -- with only a little coaxing -- it opens the lock."
          ])
        }
      ]
    },
    2: {
      label:
        "The unattended food storage cabinet is secure. " +
        "The shiny surface, which I lack a reflection in, repels direct attack. " +
        "Through the keyhole I can see something delicious.",
      options: [
        {
          skills: () => [bat2],
          locked: "If only were smaller...",
          unlockable: "I am small enough to crawl through.",
          unlockScene: compile([
            "There's a bat inside me. I guess it's like that with every vampire.",
            "I can fight, if I try, to keep it inside. But that's not how we want it.",
            "And in the second before I let it out -- as the soft fur behind my ears begins to sprout -- I feel a sense of relief.",
            "A sense of gratitude.",
            "I can't resist it now. It's urgent. I shed the rest of my mass.",
            "Now I'm as sleek and narrow as a dart --",
            "I'm inside."
          ])
        }
      ]
    }
  }
})

export default mapZoo;